@@ -2,13 +2,14 @@ use crate::{
   config::Config,
   error::{self, Error, Result},
   file_stream::FileStream,
+  html,
   input_path::InputPath,
   redirect::redirect,
 };
 use agora_lnd_client::lnrpc::invoice::InvoiceState;
 use hyper::{header, Body, Request, Response, StatusCode};
 use lexiclean::Lexiclean;
-use maud::{html, Markup, DOCTYPE};
+use maud::{html, Markup};
 use percent_encoding::{AsciiSet, NON_ALPHANUMERIC};
 use snafu::{IntoError, ResultExt};
 use std::{
@@ -84,6 +85,10 @@ impl Files {
     Ok(())
   }
 
+  fn config_for_dir(&self, dir: &Path) -> Result<Config> {
+    Config::for_dir(self.base_directory.as_ref(), dir)
+  }
+
   pub(crate) async fn serve(
     &mut self,
     request: &Request<Body>,
@@ -143,25 +148,6 @@ impl Files {
     Ok(entries)
   }
 
-  fn serve_html(body: Markup) -> Response<Body> {
-    let html = html! {
-      html {
-        (DOCTYPE)
-        head {
-          meta charset="utf-8";
-          title {
-            "agora"
-          }
-          link rel="stylesheet" href="/static/index.css";
-        }
-        body {
-          (body)
-        }
-      }
-    };
-    Response::new(Body::from(html.into_string()))
-  }
-
   const ENCODE_CHARACTERS: AsciiSet = NON_ALPHANUMERIC.remove(b'/');
 
   fn render_index(dir: &InputPath) -> Result<Option<Markup>> {
@@ -186,6 +172,7 @@ impl Files {
   }
 
   async fn serve_dir(&self, dir: &InputPath) -> Result<Response<Body>> {
+    let config = self.config_for_dir(dir.as_ref())?;
     let body = html! {
       ul class="listing" {
         @for (file_name, file_type) in self.read_dir(dir).await? {
@@ -201,7 +188,7 @@ impl Files {
             a href=(encoded) class="view" {
               (file_name)
             }
-            @if file_type.is_file() {
+            @if file_type.is_file() && !config.paid() {
               a download href=(encoded) {
                 (Files::download_icon())
               }
@@ -215,7 +202,7 @@ impl Files {
         }
       }
     };
-    Ok(Files::serve_html(body))
+    Ok(html::wrap_body(body))
   }
 
   fn download_icon() -> Markup {
@@ -227,8 +214,7 @@ impl Files {
   }
 
   async fn access_file(&mut self, tail: &[&str], path: &InputPath) -> Result<Response<Body>> {
-    let config = Config::for_dir(
-      self.base_directory.as_ref(),
+    let config = self.config_for_dir(
       path
         .as_ref()
         .parent()
@@ -299,7 +285,7 @@ impl Files {
       }
       _ => {
         let qr_code_url = format!("/invoice/{}.svg", hex::encode(invoice.r_hash));
-        Ok(Files::serve_html(html! {
+        Ok(html::wrap_body(html! {
           div class="invoice" {
             div class="label" {
               (format!("Lightning Payment Request for {} to access ", value))
